/*
 * Copyright (c) 2015, Lawrence Livermore National Laboratory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Peter D. Barnes, Jr. <pdbarnes@llnl.gov>
 */

#include "mesh-stack-installer.h"

namespace ns3
{
NS_OBJECT_ENSURE_REGISTERED(MeshStack);

TypeId
MeshStack::GetTypeId()
{
    static TypeId tid = TypeId("ns3::MeshStack").SetParent<Object>().SetGroupName("Mesh")
        // No AddConstructor because this is an abstract class.
        ;
    return tid;
}

} // namespace ns3
